# catkin_tools [![Build Status](https://travis-ci.org/catkin/catkin_tools.svg?branch=master)](https://travis-ci.org/catkin/catkin_tools)

Command line tools for working with [catkin](https://github.com/ros/catkin)

Documentation: http://catkin-tools.readthedocs.org/
